@@ -48,7 +48,7 @@ void save_mod_file(MainView *mainview);
 char *get_confirmed_pass(MainView *mainview);
 
 /* activate grid */
-void callback_activate_iconView(GtkIconView *iconview, GtkTreePath *path, MainView *mainview) {
+void callback_activate_treeView(GtkTreeView *treeView, GtkTreePath *path, MainView *mainview) {
 	GtkTreeIter iter;
 	rec *onrec=NULL;
 	g_assert(mainview != NULL && mainview->data != NULL );
@@ -61,14 +61,10 @@ void callback_activate_iconView(GtkIconView *iconview, GtkTreePath *path, MainVi
 	/*
 	onrec=g_object_get_data (G_OBJECT(&iter), "r");
 	*/
-	if (onrec==NULL) {
-		populate_iconView(mainview, ""); 
-	} else {
-		if ((onrec->group==NULL) || (strcmp(showing_group, onrec->group)==0)) {
-			show_rec(mainview, onrec);
-		} else {
-			populate_iconView(mainview, onrec->group); 
-		}
+	if (onrec!=NULL) {
+		show_rec(mainview, onrec);
+	} else if (gtk_tree_view_collapse_row(treeView, path)) {
+		gtk_tree_view_expand_row(treeView, path, FALSE);
 	}
 }
 
@@ -129,7 +125,7 @@ void callback_rec_response(GtkDialog *dialog, gint arg1, MainView *mainview) {
 			}
 			resort_rec(rec);
 			unshow_rec(mainview);  /* close rec window */
-			populate_iconView(mainview, showing_group); /* redraw grid */
+			populate_treeView(mainview); /* redraw grid */
 			break;
 		case 2:
 			gtk_clipboard_set_text(mainview->clipboard, rec->user, -1);
@@ -141,12 +137,16 @@ void callback_rec_response(GtkDialog *dialog, gint arg1, MainView *mainview) {
 			if ((recwindow->editable) && (CONFRESP_YES==interface_yes_no_note(mainview, "Confirm Delete?"))) {
 				unshow_rec(mainview);
 				delete_rec(rec);
-				populate_iconView(mainview, showing_group); /* redraw grid */
+				populate_treeView(mainview); /* redraw grid */
 			}
 			break;
 		case 5:
 			interface_set_rec_editable(recwindow, TRUE);
 			break;
+		case -4:
+			unshow_rec(mainview);  /* close rec window */
+			populate_treeView(mainview); /* redraw grid */
+			break;
 	}
 }
 
@@ -209,12 +209,18 @@ void save_mod_file(MainView *mainview) {
     }
 }
 
+gchar * getCurrentGroup(MainView *mainview ) {
+	//TODO get the current Group from the selected one
+	gchar *group = g_strdup("");
+	return group;
+}
+
 /* add entry */
 void callback_add_entry ( GtkAction * action, MainView *mainview ) {
 	rec* newrec=NULL;
 	g_assert(mainview != NULL && mainview->data != NULL );
-	newrec=add_new_record("new", showing_group);
-	populate_iconView(mainview, showing_group);
+	newrec=add_new_record("new", getCurrentGroup(mainview));
+	populate_treeView(mainview);
 	show_rec(mainview, newrec);
     interface_set_rec_editable(mainview->rec_win, TRUE);
 }
@@ -260,9 +266,8 @@ void callback_file_new(GtkAction * action, MainView *mainview) {
 	newpass=get_confirmed_pass(mainview);
 	if (newpass) {
 		mainview->pass=newpass;
-		showing_group="";
-		add_new_record("new", showing_group);
-		populate_iconView(mainview, "");
+		add_new_record("new", getCurrentGroup(mainview));
+		populate_treeView(mainview);
         /* maybe_save_file(mainview); */
         write_pwsafe_file(mainview);  /* force set file name */
 	}
@@ -312,15 +317,6 @@ void callback_fullscreen( GtkAction * action, gpointer data ) {
 	interface_fullscreen((MainView *) data);
 }
 
-/* icon size */
-void callback_large_icons( GtkAction * action, MainView *mainview ) {
-	interface_set_icon_size(mainview, "largeicons");
-}
-
-/* icon size */
-void callback_small_icons( GtkAction * action, MainView *mainview ) {
-	interface_set_icon_size(mainview, "smallicons");
-}
 
 /* filter */
 
@@ -357,7 +353,7 @@ void callback_filter( GtkAction * action, MainView *mainview ) {
             onrec=g_list_next(onrec);
         }
     }
-    populate_iconView(mainview, "");
+    populate_treeView(mainview);
 }
 
 /* export */
