@@ -83,24 +83,15 @@ MainView* interface_main_view_new( AppData *data ) {
 	create_toolbar( result ); 
 	create_menu( result );
 	/* Put mainwindow to GTK vbox and show it */
-/*
-	gtk_container_add( GTK_CONTAINER( result->data->main_view ), main_vbox );
-	gtk_box_pack_start( GTK_BOX( main_vbox ), result->iconView, TRUE, TRUE, 0 );
-	gtk_widget_show( main_vbox );
-*/
 	gtk_container_add( GTK_CONTAINER( result->data->main_view ), scrolled_window );
-	gtk_container_add( GTK_CONTAINER( scrolled_window ), result->iconView);
+	gtk_container_add( GTK_CONTAINER( scrolled_window ), result->treeView);
 	gtk_widget_show( scrolled_window );
-	gtk_widget_grab_focus( GTK_WIDGET(result->iconView ));
+	gtk_widget_grab_focus( GTK_WIDGET(result->treeView ));
 	/* attach handlers */
 	osso_hw_set_event_cb( data->osso, NULL,(osso_hw_cb_f *) hw_event_handler, result);
 //	osso_application_set_exit_cb( data->osso, exit_event_handler, result);
 	g_signal_connect (G_OBJECT(data->main_view), "delete_event", G_CALLBACK(exit_event_handler), result);	/* top right X, etc. */
 	g_signal_connect(G_OBJECT(result->data->main_view), "key_press_event", G_CALLBACK(callback_key_press), result);
-	/* loadup empty iconView */
-/*
-	populate_iconView(result, "");
-*/
 	return result; /* Return new mainview handle */
 }
 
@@ -178,56 +169,68 @@ void show_rec(MainView *main, rec *r) {
 	interface_set_rec_editable(rec_win, FALSE);
 }
 
-void empty_iconView(MainView *main) {
-	 gtk_list_store_clear(main->store);
+void empty_treeView(MainView *main) {
+	 gtk_tree_store_clear(main->store);
 }
 
-void addItemToIconView(MainView *main, gchar *label, gchar *stockId, rec *data) {
+
+gboolean addEntryToGroup(GtkTreeStore *store, GtkTreeIter *groupIter, rec *data) {
 	GtkTreeIter iter;
-	GdkPixbuf *pixBuf;
-	pixBuf = gtk_widget_render_icon(main->iconView, stockId, main->iconSize, "");
-	gtk_list_store_append(main->store, &iter);
-	gtk_list_store_set(main->store, &iter, LABEL_COLUMN, label, ICON_COLUMN, pixBuf, DATA_COLUMN, data,  -1);
-	g_object_unref(pixBuf);
-/*
-	if (data) {
-		g_object_set_data (G_OBJECT(&iter), "r", data);
-	}
-*/
+	
+	gtk_tree_store_append(store, &iter, groupIter);
+	gtk_tree_store_set(store, &iter, LABEL_COLUMN, data->title, ICON_COLUMN, GTK_STOCK_FILE, DATA_COLUMN, data,  -1);
+	return TRUE;
 }
 
-void populate_iconView (MainView *main, char *group) {
+gboolean searchGroup (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter, SearchGroup *sg) {
+	rec *data;
+	gchar *label;
+	
+	gtk_tree_model_get(model, iter, LABEL_COLUMN, &label, DATA_COLUMN, &data,  -1);
+	if (data == NULL && label != NULL && g_ascii_strcasecmp( emptynull(sg->data->group), label) == 0) {
+		sg->found = addEntryToGroup(GTK_TREE_STORE(model), iter, sg->data);
+		
+		return TRUE;
+	}
+	return FALSE;
+}
+
+gboolean addEntryToTree(MainView *main, rec *data) {
+	SearchGroup *sg;
+	GtkTreeIter groupIter;
+	
+	sg = g_new0(SearchGroup, 1);
+	sg->data = data;
+	gtk_tree_model_foreach(GTK_TREE_MODEL(main->store), (GtkTreeModelForeachFunc) searchGroup, (gpointer) sg);
+	if (sg->found == TRUE) {
+		g_free(sg);
+		return TRUE;
+	}
+	g_free(sg);
+	
+	//Create the group 
+	gtk_tree_store_append(main->store, &groupIter, NULL);
+	gtk_tree_store_set(main->store, &groupIter, LABEL_COLUMN, emptynull(data->group), ICON_COLUMN, GTK_STOCK_DIRECTORY, DATA_COLUMN, NULL, -1);
+	
+	//Add the Entry
+	addEntryToGroup(main->store, &groupIter, data);
+	
+	return FALSE;
+}
+
+void populate_treeView (MainView *main) {
 	GList *onrec=NULL;
-	char *lastgroup="";
 	
 	g_assert(main != NULL && main->data != NULL );
-	showing_group=group;
-	empty_iconView(main);
+	empty_treeView(main);
 
-	gtk_icon_view_set_item_width (GTK_ICON_VIEW(main->iconView), ((main->iconView->allocation.width) / gtk_icon_view_get_columns (GTK_ICON_VIEW(main->iconView)))-30);
-	
 	onrec=g_list_first(recs);
-	if (onrec!=NULL) {
-		/* add 'parent directory to non-root folders */
-		if (group[0]!='\0') {
-			addItemToIconView(main, "[Parent Folder]", GTK_STOCK_DIRECTORY, NULL);
-		}
-	}
 	while (onrec!=NULL) {
-		rec *data=(rec *) onrec->data;
-        if (data->skip == 0) {
-            if (strcmp(emptynull(data->group), group)==0) {
-                addItemToIconView(main, emptynull(data->title), GTK_STOCK_FILE, data);
-            } else {
-                if (group[0]=='\0') { /* show all groups at top level */
-                    if (strcmp(lastgroup, emptynull(data->group))!=0) { /* supress duplicate group folders */
-                        addItemToIconView(main, data->group, GTK_STOCK_DIRECTORY, data);
-                        lastgroup=data->group;
-                    }
-                }
-            }
-        }
-		onrec=g_list_next(onrec);
+	    rec *data=(rec *) onrec->data;
+	    if (data->skip == 0) {
+		addEntryToTree(main, data);
+      	    }
+	    onrec=g_list_next(onrec);
 	}
 	interface_show_state(main);
 }
@@ -326,10 +329,6 @@ static void create_menu( MainView *main )
 	main->saveas_item = gtk_menu_item_new_with_label ( _("Save As...") );
     main->export_item = gtk_menu_item_new_with_label ( _("Export...") );
 	
-	main->view_item = gtk_menu_item_new_with_label ( _("View") );
-	main->large_icons_item = gtk_menu_item_new_with_label ( _("Large Icons") );
-	main->small_icons_item = gtk_menu_item_new_with_label ( _("Small Icons") );
-	
 	main->fullscreen_item = gtk_menu_item_new_with_label ( _("Full Screen") );
 	main->add_item = gtk_menu_item_new_with_label ( _("Add Entry") );
 	main->change_password = gtk_menu_item_new_with_label ( _("Change Password") );
@@ -346,10 +345,6 @@ static void create_menu( MainView *main )
 	gtk_menu_append( file_menu, main->saveas_item );
     gtk_menu_append( file_menu, main->export_item );
  
-	gtk_menu_append( main_menu, main->view_item );
-	gtk_menu_append( view_menu, main->large_icons_item );
-	gtk_menu_append( view_menu, main->small_icons_item );
-	
 	gtk_menu_append( main_menu, main->add_item );
 	gtk_menu_append( main_menu, main->change_password );
 	gtk_menu_append( main_menu, main->fullscreen_item );
@@ -368,8 +363,6 @@ static void create_menu( MainView *main )
 	g_signal_connect( G_OBJECT( main->save_item ), "activate",  G_CALLBACK ( callback_file_save), main );
 	g_signal_connect( G_OBJECT( main->saveas_item ), "activate",  G_CALLBACK ( callback_file_saveas), main );
     g_signal_connect( G_OBJECT( main->export_item ), "activate",  G_CALLBACK ( callback_export), main );
-	g_signal_connect( G_OBJECT( main->large_icons_item ), "activate",  G_CALLBACK ( callback_large_icons), main );
-	g_signal_connect( G_OBJECT( main->small_icons_item ), "activate",  G_CALLBACK ( callback_small_icons), main );
 	g_signal_connect( G_OBJECT( main->add_item ), "activate",  G_CALLBACK ( callback_add_entry), main );
 	g_signal_connect( G_OBJECT( main->change_password ), "activate",  G_CALLBACK ( callback_change_password), main );
 	g_signal_connect( G_OBJECT( main->fullscreen_item ), "activate",  G_CALLBACK ( callback_fullscreen ), main );
@@ -487,16 +480,31 @@ static void create_toolbar ( MainView *main ) {
 
 /* Create the main grid */
 void create_textarea( MainView *main ) {
+	GtkCellRenderer *renderer;
+        GtkTreeViewColumn *column;
+	GtkTreeSelection *select;
+		
 	main->font_desc = pango_font_description_from_string ("Nokia Sans 16");
-	main->store=gtk_list_store_new (N_COLUMNS, G_TYPE_STRING, GDK_TYPE_PIXBUF, G_TYPE_POINTER);
-	main->iconView=gtk_icon_view_new_with_model(GTK_TREE_MODEL(main->store));
-	gtk_icon_view_set_text_column (GTK_ICON_VIEW(main->iconView), LABEL_COLUMN);
-	gtk_icon_view_set_pixbuf_column (GTK_ICON_VIEW(main->iconView), ICON_COLUMN);
-	gtk_icon_view_set_spacing (GTK_ICON_VIEW(main->iconView), 10);
-	main->iconSize = GTK_ICON_SIZE_SMALL_TOOLBAR;
-	gtk_widget_show(main->iconView);
+	main->store=gtk_tree_store_new (N_COLUMNS, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_POINTER);
+	main->treeView=gtk_tree_view_new_with_model(GTK_TREE_MODEL(main->store));
+#if MAEMO_VERSION_MAJOR == 5
+	gtk_tree_view_set_show_expanders(GTK_TREE_VIEW (main->treeView), TRUE);
+#endif
+	renderer = gtk_cell_renderer_pixbuf_new();
+	column = gtk_tree_view_column_new_with_attributes (_("Icon"), renderer, "stock-id", ICON_COLUMN, NULL);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (main->treeView), column);
+
+	renderer = gtk_cell_renderer_text_new ();
+        column = gtk_tree_view_column_new_with_attributes (_("Label"), renderer, "text", LABEL_COLUMN, NULL);
+        gtk_tree_view_append_column (GTK_TREE_VIEW (main->treeView), column);
+	gtk_widget_show(main->treeView);
+        /* Setup the selection handler */
+        select = gtk_tree_view_get_selection (GTK_TREE_VIEW (main->treeView));
+        gtk_tree_selection_set_mode (select, GTK_SELECTION_SINGLE);
+        gtk_tree_view_columns_autosize(GTK_TREE_VIEW(main->treeView));
+				
     /* Connect signals */
-	g_signal_connect (G_OBJECT(main->iconView), "item-activated", G_CALLBACK (callback_activate_iconView), main);
+	g_signal_connect (G_OBJECT(main->treeView), "hildon-row-tapped", G_CALLBACK (callback_activate_treeView), main);
 }
 
 /* toggle fullscreen */
@@ -510,26 +518,3 @@ void interface_fullscreen(MainView *mainview) {
 	}
 }
 
-/* set grid icon size */
-void interface_set_icon_size(MainView *mainview, gchar *style) {
-/* style may have come from gconf... don't trust it */
-	gchar *safe_style;
-	GtkIconSize iconSize;
-	g_assert(mainview != NULL && mainview->data != NULL );
-	
-	if ((style) && (strcmp("largeicons", style)==0)) {
-		safe_style="largeicons";
-		iconSize = GTK_ICON_SIZE_DIALOG;
-		gtk_icon_view_set_orientation (GTK_ICON_VIEW(mainview->iconView), GTK_ORIENTATION_VERTICAL);
-		gtk_icon_view_set_columns (GTK_ICON_VIEW(mainview->iconView), 3);
-	} else {
-		safe_style="smallicons";
-		iconSize = GTK_ICON_SIZE_BUTTON;
-		gtk_icon_view_set_orientation (GTK_ICON_VIEW(mainview->iconView), GTK_ORIENTATION_HORIZONTAL);
-		gtk_icon_view_set_columns (GTK_ICON_VIEW(mainview->iconView), 2);
-	}
-	conf_save_string(CONF_ICONSIZE, safe_style);
-	mainview->iconSize = iconSize;
-	populate_iconView(mainview, showing_group)	;
-}
-
