@@ -109,11 +109,6 @@ int main( int argc, char* argv[] ) {
 	gtk_widget_show ( GTK_WIDGET ( data->main_view ) );
 
 	main_view->last_file=conf_get_string(CONF_LASTFILE);
-	{
-		gchar *iconsize=conf_get_string(CONF_ICONSIZE);
-		interface_set_icon_size(main_view, iconsize);
-		g_free(iconsize);
-	}
 	g_signal_emit_by_name(G_OBJECT(main_view->open_last_item), "activate");
 	
 	gtk_main();
